# bitcoinfees

[![Build Status](https://travis-ci.com/daveusa31/bitcoinfees.svg?branch=master)](https://travis-ci.com/daveusa31/bitcoinfees)
[![PyPi Package Version](https://img.shields.io/pypi/v/bitcoinfees.svg?style=flat-square)](https://pypi.python.org/pypi/bitcoinfees)
[![PyPi status](https://img.shields.io/pypi/status/bitcoinfees.svg?style=flat-square)](https://pypi.python.org/pypi/bitcoinfees)
[![Downloads](https://pepy.tech/badge/bitcoinfees)](https://pepy.tech/project/bitcoinfees)
[![Supported python versions](https://img.shields.io/pypi/pyversions/bitcoinfees.svg?style=flat-square)](https://pypi.python.org/pypi/bitcoinfees)
[![repository size](https://img.shields.io/github/repo-size/daveusa31/bitcoinfees)](https://pypi.python.org/pypi/bitcoinfees)